@@ -1,13 +1,12 @@
 # $File: //depot/OurNet-BBS/BBS/MAPLE2/BBS.pm $ $Author: autrijus $
-# $Revision: #2 $ $Change: 1134 $ $DateTime: 2001/06/14 18:08:06 $
+# $Revision: #3 $ $Change: 1525 $ $DateTime: 2001/08/17 22:49:33 $
 
 package OurNet::BBS::MAPLE2::BBS;
 
 use strict;
 use base qw/OurNet::BBS/;
 use fields qw/backend bbsroot brdshmkey maxboard sessionshmkey maxsession
-              usershmkey maxuser chatport passwd _cache/;
-
-BEGIN { __PACKAGE__->initvars() }
+              usershmkey maxuser chatport passwd _ego _hash/;
+use OurNet::BBS::Base;
 
 1;
