@@ -1,24 +1,21 @@
 # $File: //depot/OurNet-BBS/BBS/MAPLE2/Board.pm $ $Author: autrijus $
-# $Revision: #7 $ $Change: 1254 $ $DateTime: 2001/06/21 10:39:30 $
+# $Revision: #13 $ $Change: 1649 $ $DateTime: 2001/09/01 21:07:24 $
 
 package OurNet::BBS::MAPLE2::Board;
 
 use strict;
-use base qw/OurNet::BBS::Base/;
-use fields qw/bbsroot board shmid shm recno mtime _cache/;
+use fields qw/bbsroot board shmid shm recno mtime _ego _hash/;
 
-BEGIN {
-    __PACKAGE__->initvars(
-        'BoardGroup' => [
-	    qw/$BRD $PATH_BRD $PATH_GEM $packsize $packstring @packlist/
-	],
-    );
-}
+use OurNet::BBS::Base (
+    'BoardGroup' => [
+        qw/$BRD $PATH_BRD $PATH_GEM $packsize $packstring @packlist/
+    ],
+);
 
 sub refresh_articles {
     my $self = shift;
 
-    return $self->{_cache}{articles} ||= $self->module('ArticleGroup')->new(
+    return $self->{_hash}{articles} ||= $self->module('ArticleGroup')->new(
         $self->{bbsroot}, $self->{board}, $PATH_BRD
     );
 }
@@ -26,7 +23,7 @@ sub refresh_articles {
 sub refresh_archives {
     my $self = shift;
 
-    return $self->{_cache}{archives} ||= $self->module('ArticleGroup')->new(
+    return $self->{_hash}{archives} ||= $self->module('ArticleGroup')->new(
         $self->{bbsroot}, $self->{board}, $PATH_GEM
     );
 }
@@ -35,6 +32,7 @@ sub post_new_board {};
 
 sub refresh_meta {
     my ($self, $key) = @_;
+
     die 'cannot parse board' unless $self->{board};
 
     if ($key and index(
@@ -45,25 +43,25 @@ sub refresh_meta {
 	# special-casing MAPLE2 note => notes:
 	$key = 'notes' if $key eq 'note' and $PATH_BRD eq 'boards';
 
-        return if exists $self->{_cache}{$key};
+        return if exists $self->{_hash}{$key};
 
         require OurNet::BBS::ScalarFile;
-        tie $self->{_cache}{$key}, 'OurNet::BBS::ScalarFile',
+        tie $self->{_hash}{$key}, 'OurNet::BBS::ScalarFile',
             "$self->{bbsroot}/$PATH_BRD/$self->{board}/$key";
 
         return 1;
     }
 
     my $file = "$self->{bbsroot}/$BRD";
-    return if $self->timestamp($file);
+    return if $self->filestamp($file);
 
     local $/ = \$packsize;
     open(my $DIR, $file) or die "can't read $BRD: $!";
 
     if (defined $self->{recno}) {
         seek $DIR, $packsize * $self->{recno}, 0;
-        @{$self->{_cache}}{@packlist} = unpack($packstring, <$DIR>);
-        if ($self->{_cache}{id} ne $self->{board}) {
+        @{$self->{_hash}}{@packlist} = unpack($packstring, <$DIR>);
+        if ($self->{_hash}{id} ne $self->{board}) {
             undef $self->{recno};
             seek $DIR, 0, 0;
         }
@@ -73,20 +71,20 @@ sub refresh_meta {
         $self->{recno} = 0;
 
         while (my $data = <$DIR>) {
-            @{$self->{_cache}}{@packlist} = unpack($packstring, $data);
-            last if ($self->{_cache}{id} eq $self->{board});
+            @{$self->{_hash}}{@packlist} = unpack($packstring, $data);
+            last if ($self->{_hash}{id} eq $self->{board});
             $self->{recno}++;
         }
 
 	no warnings 'uninitialized';
 
-        if ($self->{_cache}{id} ne $self->{board}) {
-            $self->{_cache}{id}       = $self->{board};
-            $self->{_cache}{bm}       = '';
-            $self->{_cache}{date}     = sprintf(
+        if ($self->{_hash}{id} ne $self->{board}) {
+            $self->{_hash}{id}       = $self->{board};
+            $self->{_hash}{bm}       = '';
+            $self->{_hash}{date}     = sprintf(
 		"%2d/%02d", (localtime)[4] + 1, (localtime)[3]
 	    );
-            $self->{_cache}{title}    = '(untitled)';
+            $self->{_hash}{title}    = '(untitled)';
 
             mkdir "$self->{bbsroot}/$PATH_BRD/$self->{board}";
             open $DIR, '>', "$self->{bbsroot}/$PATH_BRD/$self->{board}/.DIR";
@@ -100,10 +98,10 @@ sub refresh_meta {
 		or die "can't write $BRD file for $self->{board}: $!";
 
 	    no warnings 'uninitialized';
-            print $DIR pack($packstring, @{$self->{_cache}}{@packlist});
-
+            print $DIR pack($packstring, @{$self->{_hash}}{@packlist});
             close $DIR;
-	    $self->post_new_board();
+
+	    $self->post_new_board;
         }
     }
 
@@ -112,22 +110,22 @@ sub refresh_meta {
 
 sub STORE {
     my ($self, $key, $value) = @_;
+    $self = $self->ego;
 
     no warnings 'uninitialized';
 
-    $self->refresh_meta($key);
-    $self->{_cache}{$key} = $value;
+    $self->refresh($key);
+    $self->{_hash}{$key} = $value;
 
     return unless $self->contains($key);
 
     my $file = "$self->{bbsroot}/$BRD";
     open (my $DIR, '+<', $file) or die "cannot open $file for writing";
-    # print "seeeking to ".($packsize * $self->{recno});
     seek $DIR, $packsize * $self->{recno}, 0;
-    print $DIR pack($packstring, @{$self->{_cache}}{@packlist});
+    print $DIR pack($packstring, @{$self->{_hash}}{@packlist});
     close $DIR;
 
-    $self->timestamp($file);
+    $self->filestamp($file);
     $self->shmtouch if exists $self->{shm};
 }
 
@@ -137,15 +135,9 @@ sub shmtouch {
 }
 
 sub remove {
-    my $self = shift;
-=emergercy fix
-    my $file = "$self->{bbsroot}/.BOARDS";
-    open DIR, "+<$file" or die "cannot open $file for writing";
-    # print "seeeking to ".($packsize * $self->{recno});
-    seek DIR, $packsize * $self->{recno}, 0;
-    print DIR "\0" x $packsize;
-    close DIR;
-=cut
+    my $self = shift->ego;
+
+    $self->remove_entry("$self->{bbsroot}/$BRD");
 
     OurNet::BBS::Utils::deltree("$self->{bbsroot}/$PATH_BRD/$self->{board}");
     OurNet::BBS::Utils::deltree("$self->{bbsroot}/$PATH_GEM/$self->{board}");
@@ -153,4 +145,37 @@ sub remove {
     return 1;
 }
 
+sub remove_entry {
+    my ($self, $file) = @_;
+    my ($before, $after) = ('', '');
+
+    $self->refresh_meta;
+
+    my $recno = $self->{recno};
+
+    open(my $DIR, $file) or die "cannot open $file for reading";
+
+    if ($recno) {
+        # before...
+        seek $DIR, 0, 0;
+        read($DIR, $before, $packsize * $self->{recno});
+    }
+
+    if ($recno < ((stat($file))[7] / $packsize) - 1) {
+        seek $DIR, $packsize * ($recno + 1), 0;
+        read(
+	    $DIR, $after, 
+	    $packsize * (
+		(stat($file))[7] - (($recno + 1) * $packsize)
+	    )
+	);
+    }
+
+    close $DIR;
+
+    open $DIR, '>', $file or die "cannot open $file for writing";
+    print $DIR $before . $after;
+    close $DIR;
+}
+
 1;
