@@ -1,15 +1,12 @@
 # $File: //depot/OurNet-BBS/BBS/MAPLE3/FileGroup.pm $ $Author: autrijus $
-# $Revision: #2 $ $Change: 1266 $ $DateTime: 2001/06/23 16:54:04 $
+# $Revision: #3 $ $Change: 1525 $ $DateTime: 2001/08/17 22:49:33 $
 
 package OurNet::BBS::MAPLE3::FileGroup;
 
 use base qw/OurNet::BBS::MAPLE2::FileGroup/;
-use fields qw/_cache/;
-
-BEGIN { 
-    __PACKAGE__->initvars(
-	'$PATH_ETC' => 'gem/@',
-    ) 
-}
+use fields qw/_ego _hash/;
+use OurNet::BBS::Base (
+    '$PATH_ETC' => 'gem/@',
+);
 
 1;
